pub struct CreateOrUpdateComputePolicyParameters {
pub properties: CreateOrUpdateComputePolicyProperties,
}Expand description
The parameters used to create a new compute policy.
Fields
properties: CreateOrUpdateComputePolicyPropertiesThe compute policy properties to use when creating a new compute policy.
Implementations
Sourceimpl CreateOrUpdateComputePolicyParameters
impl CreateOrUpdateComputePolicyParameters
pub fn new(properties: CreateOrUpdateComputePolicyProperties) -> Self